@@ -15,7 +15,7 @@ os.environ['TF_CPP_MIN_LOG_LEVEL'] = '2'
 # 3 = INFO, WARNING, and ERROR messages are not printed
 
 
-def preprocess(DIR, categories, size, isSave=True ):
+def preprocess(DIR, categories, size, name, isSave=True ):
     """
     Reads Images in image paths
     Returns
@@ -27,7 +27,7 @@ def preprocess(DIR, categories, size, isSave=True ):
     try:
         # If train.npy already exists, load it in
         # if os.path.exists('featureSet.npy')
-        train = np.load('train.npy', allow_pickle=True)
+        train = np.load(f'{name}.npy', allow_pickle=True)
         print('[INFO] Loading from Numpy Files')
     except:
         print('[INFO] Generating the Image Files')
@@ -53,7 +53,7 @@ def preprocess(DIR, categories, size, isSave=True ):
 
         # Saves the Train set as a .npy file
         if isSave == True:
-            saveNumpy(train)
+            saveNumpy(name, train)
 
     #Returns Training Set
     return train
