@@ -26,13 +26,13 @@ def readToGray(image,size):
     except:
         pass
 
-def saveNumpy(x):
+def saveNumpy(name, x):
     """
     Saves an array to a .npy file
     Converts to Numpy (if not already)
     """
     x = np.array(x)
-    np.save(str(x), x)
+    np.save(name, x)
 
 def train_val_split(X,y,val_ratio=.2):
     """
